@@ -16,12 +16,16 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include <config.h>
+#ifdef GNOME_GTKHTML_EDITOR_SHLIB
+#include <glib/gi18n-lib.h>
+#else
 #include <glib/gi18n.h>
+#endif
 #include <string.h>
 #include <bonobo.h>
 
@@ -34,7 +38,7 @@
 #include "htmlundo.h"
 
 #include "engine.h"
-#include "spell.h"
+#include "spellchecker.h"
 
 static BonoboObjectClass *engine_parent_class;
 
@@ -283,5 +287,12 @@ editor_engine_new (GtkHTMLControlData *cd)
 
 	ee->cd = cd;
 
+	/* This engine will be returned to the composer window.
+	 * The html-widget will be used by the composer to 
+	 * provide DnD to the composer window's GtkHTML component
+	 */
+
+	g_object_set_data ((GObject *)ee, "html-widget", cd->html);
+	
 	return ee;
 }
