@@ -24,8 +24,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ * 02110-1301, USA.
  */
 
 #include <config.h>
@@ -35,6 +35,11 @@
 #include <libgnomecanvas/gnome-canvas.h>
 #include <libgnomecanvas/gnome-canvas-pixbuf.h>
 #include <libgnomecanvas/gnome-canvas-rect-ellipse.h>
+#ifdef GNOME_GTKHTML_EDITOR_SHLIB
+#include <glib/gi18n-lib.h>
+#else
+#include <glib/gi18n.h>
+#endif
 #include "htmlmarshal.h"
 #include "gi-colors.h"
 #include "gi-color-combo.h"
@@ -145,8 +150,8 @@ color_table_setup (GiColorCombo *cc,
 						  color_group));
 
 	{
-		GtkWidget *picker = color_palette_get_color_picker (cc->palette);
-		g_signal_connect (picker, "clicked",
+		GtkWidget *color_button = color_palette_get_color_picker (cc->palette);
+		g_signal_connect (color_button, "clicked",
 				  G_CALLBACK (cb_cust_color_clicked), cc);
 	}
 
@@ -183,6 +188,7 @@ gi_color_combo_construct (GiColorCombo *cc, GdkPixbuf *icon,
 	 * Our button with the canvas preview
 	 */
 	cc->preview_button = gtk_button_new ();
+	atk_object_set_name (gtk_widget_get_accessible (cc->preview_button), _("color preview"));
 	gtk_button_set_relief (GTK_BUTTON (cc->preview_button), GTK_RELIEF_NONE);
 
 	cc->preview_canvas = GNOME_CANVAS (gnome_canvas_new ());
@@ -197,7 +203,7 @@ gi_color_combo_construct (GiColorCombo *cc, GdkPixbuf *icon,
 			"y",      0.0,
 			"anchor", GTK_ANCHOR_NW,
 			NULL);
-		gdk_pixbuf_unref (icon);
+		g_object_unref (icon);
 
 		cc->preview_color_item = gnome_canvas_item_new (
 			GNOME_CANVAS_GROUP (gnome_canvas_root (cc->preview_canvas)),
@@ -222,7 +228,7 @@ gi_color_combo_construct (GiColorCombo *cc, GdkPixbuf *icon,
 			NULL);
 
 	gtk_container_add (GTK_CONTAINER (cc->preview_button), GTK_WIDGET (cc->preview_canvas));
-	gtk_widget_set_usize (GTK_WIDGET (cc->preview_canvas), 24, 22);
+	gtk_widget_set_size_request (GTK_WIDGET (cc->preview_canvas), 24, 22);
 	g_signal_connect (cc->preview_button, "clicked",
 			  G_CALLBACK (preview_clicked), cc);
 
