@@ -15,8 +15,8 @@
    
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #ifndef _HTMLGDKPAINTER_H
@@ -71,10 +71,5 @@ void               html_gdk_painter_realize                          (HTMLGdkPai
 								      GdkWindow             *window);
 void               html_gdk_painter_unrealize                        (HTMLGdkPainter        *painter);
 gboolean           html_gdk_painter_realized                         (HTMLGdkPainter        *painter);
-HTMLTextPangoInfo *html_gdk_painter_text_itemize_and_prepare_glyphs  (HTMLGdkPainter        *painter,
-								      PangoFontDescription  *desc,
-								      const gchar           *text,
-								      gint                   bytes,
-								      GList                **glyphs);
 
 #endif /* _HTMLGDKPAINTER_H */
